/*
 *
 * Use mikroE Timer Calculator to generate proper timer configuration
 * and timer ISR. https://www.mikroe.com/timer-calculator
 *
*/

#include "Click_G2C3G_types.h"

uint32_t task_time = 0;

// Timer interrupt configurration 
// [STM32F407ZG / 168MHz / 10ms]
void g2c3g_timer_int_cfg( )
{
    RCC_APB1ENR.TIM2EN = 1;
    TIM2_CR1.CEN = 0;
    TIM2_PSC = 27;
    TIM2_ARR = 59999;
    NVIC_IntEnable(IVT_INT_TIM2);
    TIM2_DIER.UIE = 1;
    TIM2_CR1.CEN = 1;
    
    task_time = 0;
}

// UART interrupt configurration
// [STM32F407ZG / MikroBUS 1]
void g2c3g_uart_int_cfg( )
{
    RXNEIE_USART6_CR1_bit = 1;
    NVIC_IntEnable( IVT_INT_USART6 );
    EnableInterrupts( );
}

// Timer routine [STM32F407ZG / 168MHz]
void timer_interrupt( ) iv IVT_INT_TIM2
{
    g2c3g_tick( );
    task_time++;
    TIM2_SR.UIF = 0;
}

// Interrupt routine [MikroBUS 4]
void UART_RX_ISR( ) iv IVT_INT_USART6 ics ICS_AUTO
{
    char tmp;

    if ( RXNE_USART6_SR_bit == 1 )
    {
        tmp = USART6_DR;
        g2c3g_putc( tmp );
    }
}